@@ -1,5 +1,6 @@
 from typing import Optional, Sequence, Tuple
 
+from django.db import models
 from django.utils.translation import get_language as django_get_language
 from django.conf import settings as django_settings
 
@@ -7,7 +8,13 @@ from .conf import settings
 from .types import FallbackLanguages, Language
 
 
-__all__ = 'get_language_choices', 'get_language', 'get_fallback_languages'
+__all__ = (
+    'get_language_choices',
+    'get_language',
+    'get_fallback_languages',
+    'is_translation',
+    'LanguageGetterMixin',
+)
 
 
 def get_language_choices(
@@ -42,3 +49,20 @@ def get_fallback_languages(
     language = language if language is not None else get_language()
 
     return language, fallback_languages.get(language) or []
+
+
+def is_translation(instance: models.Model):
+    # FIXME: There could be an instance with some relation to another
+    # "entity". So this check should be improved to be more accurate.
+    return (
+        hasattr(instance, 'entity_id')
+        and
+        hasattr(instance, 'language')
+        and
+        isinstance(instance.language, str)
+    )
+
+
+class LanguageGetterMixin:
+    def get_language(self):
+        return get_language()
